/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "MessageEvent.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomDOMWindow.h"
#include "gdom/GdomEvent.h"
#include "gdom/GdomMessageEvent.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomDOMWindow.h"
#include "gdom/PrivateGdomEvent.h"
#include "gdom/PrivateGdomMessageEvent.h"
#include "gdom/PrivateIntGdomDOMWindow.h"
#include "gdom/PrivateIntGdomMessageEvent.h"
#include "glib-object.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMMessageEvent::GDOMMessageEvent(PassRefPtr<WebCore::MessageEvent> impl)
    : GDOMEvent(impl)
{
}

void
gdom_message_event_init_message_event (GdomMessageEvent *thiz, gchar * type_arg, gboolean can_bubble_arg, gboolean cancelable_arg, gchar * data_arg, gchar * origin_arg, gchar * last_event_id_arg, GdomDOMWindow * source_arg)
{
    g_return_if_fail (thiz);
    WebCore::MessageEvent * item = (gdom_message_event_get_private(thiz));
    g_return_if_fail (item);
    g_return_if_fail (type_arg);
    g_return_if_fail (data_arg);
    g_return_if_fail (origin_arg);
    g_return_if_fail (last_event_id_arg);
    g_return_if_fail (source_arg);
    WebCore::String _g_type_arg = WebCore::String::fromUTF8(type_arg);
    WebCore::String _g_data_arg = WebCore::String::fromUTF8(data_arg);
    WebCore::String _g_origin_arg = WebCore::String::fromUTF8(origin_arg);
    WebCore::String _g_last_event_id_arg = WebCore::String::fromUTF8(last_event_id_arg);
    WebCore::DOMWindow * _g_source_arg = (gdom_dom_window_get_private(source_arg));
    g_return_if_fail (_g_source_arg);
    item->initMessageEvent(_g_type_arg, can_bubble_arg, cancelable_arg, _g_data_arg, _g_origin_arg, _g_last_event_id_arg, _g_source_arg);

}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "MessageEvent.h"
#include <gdom/GdomMessageEvent.h>
#include <gdom/PrivateGdomMessageEvent.h>
#include <gdom/PrivateIntGdomMessageEvent.h>
#include <gdom/GdomMessageEventprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomMessageEvent, gdom_message_event, GDOM_TYPE_EVENT);

/*
struct _GdomMessageEventPrivate {
    class WebCore::MessageEvent *item;
};

#define GDOM_MESSAGE_EVENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_MESSAGE_EVENT, GdomMessageEventPrivate))
*/
G_END_DECLS
WebCore::MessageEvent *
gdom_message_event_get_private(GdomMessageEvent *request)
{
    GDOMMessageEvent *res;
    res = static_cast<GDOMMessageEvent*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::MessageEvent*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_DATA,
    PROP_ORIGIN,
    PROP_LAST_EVENT_ID,
    PROP_SOURCE,
};


static void gdom_message_event_finalize(GObject* object)
{
    /*GdomMessageEvent* request = GDOM_MESSAGE_EVENT(object);*/
    /*GdomMessageEventPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_EVENT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_message_event_parent_class)->finalize(object);
}

static void gdom_message_event__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomMessageEvent *self = GDOM_MESSAGE_EVENT(object);
    WebCore::MessageEvent * gself = (gdom_message_event_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_message_event__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomMessageEvent *self = GDOM_MESSAGE_EVENT(object);
    WebCore::MessageEvent * gself = (gdom_message_event_get_private(self));
    switch (prop_id) {
    case PROP_DATA:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->data()));
         break;
    }
    case PROP_ORIGIN:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->origin()));
         break;
    }
    case PROP_LAST_EVENT_ID:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->lastEventId()));
         break;
    }
    case PROP_SOURCE:
    {
         PassRefPtr<WebCore::DOMWindow> ptr = gself->source();
        g_value_set_object (value, WebCore::toGDOM(ptr.get()));
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_message_event_class_init(GdomMessageEventClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_message_event_finalize;
    g_klass->set_property = gdom_message_event__set_property_fn;
    g_klass->get_property = gdom_message_event__get_property_fn;

    g_object_class_install_property (g_klass, PROP_DATA,
            g_param_spec_string ("data", /* name */
                "message_event_data", /* short description */
                "read-only  gchar * MessageEvent.data", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_ORIGIN,
            g_param_spec_string ("origin", /* name */
                "message_event_origin", /* short description */
                "read-only  gchar * MessageEvent.origin", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_LAST_EVENT_ID,
            g_param_spec_string ("last_event_id", /* name */
                "message_event_last_event_id", /* short description */
                "read-only  gchar * MessageEvent.last_event_id", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_SOURCE,
            g_param_spec_object ("source", /* name */
                "message_event_source", /* short description */
                "read-only  GdomDOMWindow * MessageEvent.source", /* longer - could do with some extra doc stuff here */
                 GDOM_TYPE_DOM_WINDOW, /* gobject type */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomMessageEventPrivate));*/
}

static void gdom_message_event_init(GdomMessageEvent* request)
{
    /*GdomMessageEventPrivate* priv = GDOM_MESSAGE_EVENT_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

